<div id="top"></div>

<br />
<div align="center">

  <h3 align="center">almirah</h3>

  <p align="center">
	<br />
	<a href="https://girishmm.github.io/almirah"><strong>Explore the docs »</strong></a>
	<br />
	<br />
	<a href="https://github.com/girishmm/almirah/issues">Report Bug</a>
	·
	<a href="https://github.com/girishmm/almirah/issues">Request Feature</a>
  </p>
</div>

## About The Project

[almirah](https://github.com/girishmm/almirah) is designed to help
organize, maintain, and access datasets efficiently. It provides tools
for defining how data is stored, tagged, and retrieved, making it
easier to work with complex data collections.

For more information on how to use
[almirah](https://github.com/girishmm/almirah) for your data projects,
please see the [documentation](https://girishmm.github.io/almirah/).

<p align="right">(<a href="#top">back to top</a>)</p>

## Acknowledgments

Thanks to Upi and Bhalla lab members for their inputs and help.

<p align="right">(<a href="#top">back to top</a>)</p>
